import datetime

from mptt.managers import TreeManager


class CustomTreeManager(TreeManager):

    epoch = datetime.datetime(1970, 1, 1)
    start = 1484159964477

    def _get_next_tree_id(self):
        return int((datetime.datetime.utcnow() - self.epoch).total_seconds() * 1000) - self.start



from django.utils import timezone
import pytz


class TimezoneMiddleware(object):

    def process_request(self, request):
        if request.user.is_authenticated():
            timezone.activate(pytz.timezone(request.user.timezone))
        else:
            timezone.deactivate()